import React, { useEffect, useState } from "react";
import { Container, Row, Col, Button, Tabs, Tab, Form } from "react-bootstrap";
import LanguageText from "components/common/languageText";
import ProductDataAccess from "dataAccess/productDataAccess";
import { connect, useDispatch } from "react-redux";
import { actions as cartActions } from "@redux/cartRedux";
import { actions as favoriteActions } from "@redux/favoriteRedux";
import cartServices from "services/cartServices";
import favoriteServices from "services/favouriteServices";
import { isUserLoggedIn } from "services/userServices";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import SliderDataAccess from "dataAccess/sliderDataAccess";
import {
  CarouselProvider,
  Slider,
  Slide,
  ButtonBack,
  ButtonNext,
} from "pure-react-carousel";
import { Link } from "react-router-dom";
import SpinnerLocal from "components/spinner";
import Rating from "react-rating";
import ReviewDataAccess from "dataAccess/reviewDataAccess";
import ReactHtmlParser from "react-html-parser";
import { toast } from "react-toastify";
import { Helmet } from "react-helmet";
import { setFlagsFromString } from "v8";

const ProductDetails = (props: any) => {
  const productId = props.match.params.productId;

  const [currency, setCurrency] = useState(null);

  useEffect(() => {
    SliderDataAccess.getSettingData()
      .then((data) => {
        // console.log(data);
        setCurrency(data.currency_symbol);
      })
      .catch((error) => {});
  }, []);

  const [windowWidth, setWindowWidth] = useState(window.innerWidth);
  const [product, setProduct] = useState(null);
  const [id, setProductId] = useState(null);
  const [name, setName] = useState("");
  const [productAttribute, setProductAttribute] = useState([]);
  const [productDescription, setProductDescription] = useState(null);
  const [productQuantity, setProductQuantity] = useState(null);
  const [rating, setRating] = useState(null);
  const [vendorShopName, setVendorShopName] = useState("");
  const [vendorTotalReview, setVendorTotalReview] = useState(null);
  const [productPrice, setProductPrice] = useState(null);
  const [productDiscountPrice, setProductDiscountPrice] = useState(null);

  const [productLargeImage, setProductLargeImage] = useState("");
  const [productSmallImages, setProductSmallImages] = useState([]);
  const [productReviews, setProductReviews] = useState(undefined);
  const [sku, setSku] = useState("");
  const [brand, setBrand] = useState("");

  const dispatch = useDispatch();
  let totalImages = 1;

  useEffect(() => {
    ProductDataAccess.getProductDetails(productId)
      .then((data) => {
        setProductId(data.data.product.id);
        setProduct(data.data.product);
        setName(data.data.product.name);
        setProductAttribute(data.data.product_attribute);
        // console.log(data.data.product_attribute);
        setProductDescription(data.data.product.description);
        setRating(data.data.product.rating.avg_rating);
        setProductQuantity(data.data.product.is_available);
        setVendorShopName(data.data.vendor.shop_name);
        setVendorTotalReview(data.data.vendor.total_review);
        setProductLargeImage(data.data.product.image1);
        setProductSmallImages(data.data.product.gallery.map(gallery => gallery.image));
        setProductPrice(data.data.product.price);
        setProductDiscountPrice(data.data.product.discount_price);
        setSku(data.data.product.sku);
        setBrand(data.data.product.brand.name);
        setProductReviews(data.data.product.product_review);

        let smallImage = [];
        for (let i = 0; i <= 4; i++) {
          if (data.data.product.gallery.length < 70) {
            smallImage.push(data.data.product.gallery[i].image);
            // console.log(data.data.product.gallery[i].image);
          }
        }
        setProductSmallImages(smallImage);
      })
      .catch((error) => {});
  }, [productId]);
  useEffect(() => {
    const handleResize = () => {
      setWindowWidth(window.innerWidth);
    };
    window.addEventListener("resize", handleResize);
    return () => window.removeEventListener("resize", handleResize);
  }, []);

  const getVisibleSlides = () => {
    if (windowWidth > 1400) {
      return 2;
    } else if (windowWidth > 1200) {
      return 2;
    } else if (windowWidth > 1000) {
      return 1;
    } else if (windowWidth > 800) {
      return 1;
    } else {
      return 1;
    }
  };

  const toggleProductLargeImage = (image) => {
    setProductLargeImage(image);
  };

  const requestToStock = (productId) => {
    ProductDataAccess.ProductRequestToStock(productId)
      .then((data) => {
        toast.success(data);
      })
      .catch((error) => {
        toast.error("Login first and send request again");
      });
  };

  const shareUrl = 'https://genx.ae/product-details/' + productId
  console.log(shareUrl)

  //   if (product == undefined || productReviews == undefined) {
  //     return <span> </span>;
  //   }
  return (
    <div className="product-details-section">
      <Helmet>
        <title> {name} | Genx </title>
        <meta name="description" content="Product Details" />
      </Helmet>
      <Container>
        <Row>
          <Col
            xl={8}
            lg={8}
            md={8}
            sm={12}
            xs={12}
            className="product-section mt-2"
          >
            <Row>
              <Col>
                <p>
                  <Link to="/">
                    {" "}
                    <span className="product-link">
                      {" "}
                      {/* All Products &nbsp; <img src="/images/arrow-right2.png" /> */}
                    </span>{" "}
                  </Link>

                  {/* <Link to={"/our-products/" + product.category_list[0].slug}>
                    <span className="product-link">
                      {" "}
                      &nbsp; {product.category_list[0].name} &nbsp;{" "}
                      <img src="/images/arrow-right2.png" />
                    </span>
                  </Link> */}

                  {/* <span className="product-link"> &nbsp; {name} &nbsp; </span> */}
                </p>
              </Col>
            </Row>
            <Row className="img-and-des">
              <Col
                xl={6}
                lg={6}
                md={12}
                sm={12}
                xs={12}
                className="product-image"
              >
                <div className="product-large">
                  <div className="image">
                    <img
                      src={productLargeImage}
                      alt=""
                      className="big-image"
                    ></img>
                  </div>
                </div>
                <CarouselProvider
                  naturalSlideWidth={5}
                  naturalSlideHeight={5}
                  totalSlides={productSmallImages.length}
                  visibleSlides={4}
                  isIntrinsicHeight={true}
                >
                  <div className="small-image-slider">
                    <div className="products-row">
                      <ButtonBack className="previous">
                        <img
                          src="/images/arroleft.png"
                          alt=""
                          className="first"
                        />
                      </ButtonBack>
                      <Slider className="slider">
                        {productSmallImages.map((image, index) => (
                          <Slide index={index} className="slide">
                            <img
                              src={image}
                              alt=""
                              className="small-img"
                              onClick={() => {
                                toggleProductLargeImage(image);
                              }}
                            ></img>
                          </Slide>
                        ))}
                      </Slider>
                      <ButtonNext className="next">
                        <img
                          src="/images/arrowrr.png"
                          alt=""
                          className="last"
                        />
                      </ButtonNext>
                    </div>
                  </div>
                </CarouselProvider>
              </Col>
              <Col
                xl={6}
                lg={6}
                md={12}
                sm={12}
                xs={12}
                className="product-description"
              >
                <h5 style={{ marginBottom: "10px" }}>{name}</h5>
                <div
                  style={{
                    marginTop: "10px",
                    marginBottom: "10px",
                    paddingBottom: "10px",
                    borderBottom: "1px solid #d6dbdf",
                  }}
                >
                  <p
                    style={{
                      fontSize: "16px",
                      marginTop: "0px",
                      marginBottom: "2px",
                    }}
                  >
                    Brand: {brand}{" "}
                  </p>
                  <p
                    style={{
                      fontSize: "16px",
                      marginTop: "0px",
                      marginBottom: "2px",
                    }}
                  >
                    SKU: {sku}{" "}
                  </p>
                  <p
                    style={{
                      fontSize: "16px",
                      marginTop: "0px",
                      marginBottom: "2px",
                    }}
                  >
                    Sold By: {vendorShopName}{" "}
                  </p>
                </div>
                {/* {rating == 0 ? (
                  " "
                ) : (
                  <div
                    className="rating-star"
                    style={{ color: "#F9C732", fontSize: "12px" }}
                  >
                    <Rating
                      emptySymbol="fa fa-star-o fa-2x"
                      fullSymbol="fa fa-star fa-2x"
                      fractions={2}
                      initialRating={rating}
                      readonly={true}
                    />
                  </div>
                )} */}
                {/* <div className="review-total">
                  {" "}
                  {product.review_count} Reviews{" "}
                </div> */}
                <div style={{ paddingTop: "10px" }}>
                  <p style={{ marginBottom: "0px" }}>
                    Availability:{" "}
                    {productQuantity === 1 ? "In stock" : productQuantity === null ? '' : "Out of stock"}{" "}
                  </p>
                </div>
                <div className="share-with">
                  {" "}
                  Share with &nbsp;
                  <a href={`https://www.facebook.com/sharer/sharer.php?u=${shareUrl}&display=popup`} target="_blank">
                    {" "}
                    <i className="fab fa-facebook" style={{color: '#414549', marginRight: 12}}/>
                  </a>
                  <a href={`https://twitter.com/intent/tweet?url=${shareUrl}`} target="_blank">
                    <i className="fab fa-twitter" style={{color: '#414549', marginRight: 12}}/>
                  </a>
                  <a href={`https://pinterest.com/pin/create/button/?url=${shareUrl}&media=${productLargeImage}&description=${productDescription}`} target="_blank">
                    <i className="fab fa-pinterest" style={{color: '#414549', marginRight: 12}}/>
                  </a>
                </div>
                {/* Shop Rating Disabled */}
                {/* <div>
                  <span>
                    {" "}
                    Shop Rating:
                    <span>
                      {" "}
                      {vendorTotalReview > 0 ? (
                        <span> ( {vendorTotalReview} ) </span>
                      ) : (
                        <span> Not rated </span>
                      )}
                    </span>
                  </span>
                </div> */}
                <br />
                {favoriteServices.isProductOnFavorite(
                  id,
                  props.favorite.favorite
                ) ? (
                  <div
                    onClick={() => {
                      dispatch(
                        favoriteActions.removeProductFromFavorite(
                          id,
                          isUserLoggedIn(props.user.user)
                        )
                      );
                    }}
                    className="favorite-icon"
                  >
                    <img
                      className="like"
                      src={process.env.PUBLIC_URL + "/images/likered.png"}
                      alt=""
                    />
                  </div>
                ) : (
                  <div
                    onClick={() => {
                      dispatch(
                        favoriteActions.addProductToFavorite(
                          id,
                          isUserLoggedIn(props.user.user)
                        )
                      );
                    }}
                    className="favorite-icon"
                  >
                    <img
                      className="like"
                      src={process.env.PUBLIC_URL + "/images/like.png"}
                      alt=""
                    />
                  </div>
                )}
                <br />
                <p className="price">
                  {currency}{" "}
                  {productDiscountPrice == 0
                    ? productPrice
                    : productDiscountPrice}{" "}
                  &nbsp;
                  {productDiscountPrice != 0 && (
                    <del className="product-before-price">
                      {currency} {productPrice}
                    </del>
                  )}
                </p>
                {productAttribute.length !== 0 &&
                  productAttribute.map((singleAttribute) => {
                    return (
                      <p className="size">
                        {" "}
                        {singleAttribute.name && (
                          <>{singleAttribute.name}: &nbsp;</>
                        )}
                        {singleAttribute.name &&
                          singleAttribute.value.map((singleValue) => (
                            <>
                              <span className="p-size">
                                {" "}
                                {singleValue.value}{" "}
                              </span>{" "}
                              &nbsp;
                            </>
                          ))}
                      </p>
                    );
                  })}
                {/* {productAttribute.length !== 0 &&
                  productAttribute.map((singleAttribute) => {
                    return (
                      <p className="color">
                        {" "}
                        {singleAttribute.name == "Color" && (
                          <>{singleAttribute.name}: &nbsp;</>
                        )}
                        {singleAttribute.name == "Color" &&
                          singleAttribute.value.map((singleValue) => (
                            <>
                              <span className={singleValue.value}></span> &nbsp;
                            </>
                          ))}
                      </p>
                    );
                  })} */}
                <div className="price-and-cart-btn">
                  {productQuantity === 0 ? (
                    <div>
                      <p
                        className="request-to-stock-product-details"
                        onClick={() => {
                          requestToStock(id);
                        }}
                      >
                        <span className="request-to-stock-btn-text-product-details">
                          Notify me
                        </span>
                      </p>
                      <span className="out-of-stock"> Out Of Stock </span>
                    </div>
                  ) : cartServices.isProductOnCart(id, props.cart) ? (
                      <p
                          className="cart-button"
                          onClick={() => {
                            dispatch(
                                cartActions.removeFromCart(
                                    id,
                                    isUserLoggedIn(props.user.user)
                                )
                            );
                          }}
                      >
                      <span className="before-click">
                        <span className="cart">
                          <img
                              className="cart-image"
                              src={
                                process.env.PUBLIC_URL + "/images/card-red.png"
                              }
                              alt=""
                          />
                        </span>
                        <span className="cart responsive-width">
                          Added
                        </span>
                      </span>
                      </p>
                  ) : (
                    <p
                      className="cart-button"
                      onClick={() => {
                        dispatch(
                          cartActions.addProductToCart(
                            id,
                            isUserLoggedIn(props.user.user)
                          )
                        );
                      }}
                    >
                      <span className="before-click">
                        <span className="cart">
                          <img
                            className="cart-image"
                            src={
                              process.env.PUBLIC_URL + "/images/card-red.png"
                            }
                            alt=""
                          />
                        </span>
                        <span className="cart responsive-width">
                          Add to Cart
                        </span>
                      </span>
                    </p>
                  )}
                </div>
              </Col>
            </Row>
            <Row>
              <Col className="tab-menu">
                <hr />
                <Tabs defaultActiveKey="details" id="uncontrolled-tab-example">
                  <Tab eventKey="details" title="Details">
                    <div>
                      <br></br>
                      <h3> Description: </h3>
                      {productDescription == null ? (
                        <p> Description is not available. </p>
                      ) : (
                        <div> {ReactHtmlParser(productDescription)} </div>
                      )}
                      {/* <p style={{ marginTop: "20px" }}>
                        Category:{" "}
                        {product.category_list.map((category) => (
                          <b> {category.name} &nbsp; </b>
                        ))}
                      </p> */}
                      <p>
                        {" "}
                        Status:{" "}
                        {productQuantity === null ? '' : productQuantity === 0 ? (
                          <b>Out Of Stock</b>
                        ) : (
                          <b>In Stock</b>
                        )}{" "}
                      </p>{" "}
                      <br></br>
                    </div>
                  </Tab>
                   <Tab eventKey="reviews" title="Reviews">
                    {productReviews?.length === 0
                        ? <div className="px-2 py-4">No review available</div>
                      : productReviews?.map((data, index) => (
                          <Row key={index} style={{ marginTop: "30px" }}>
                            <Col xs="auto">
                              <div>
                                <img
                                  src={data.user.image ?? '/images/user.png'}
                                  alt=""
                                  style={{
                                    width: "80px",
                                    height: "80px",
                                    borderRadius: "80px",
                                  }}
                                />
                              </div>
                            </Col>
                            <Col>
                              <b>{data.user.name}</b> reviews &nbsp;
                              <span
                                style={{ color: "#F9C732", fontSize: "10px" }}
                              >
                                <Rating
                                  emptySymbol="fa fa-star-o fa-2x"
                                  fullSymbol="fa fa-star fa-2x"
                                  fractions={1}
                                  readonly={true}
                                  initialRating={data.rating}
                                />
                                <span
                                  style={{
                                    fontSize: "20px",
                                    color: "#40bfff",
                                    paddingLeft: "8px",
                                  }}
                                >
                                  {data.rating}
                                </span>
                              </span>{" "}
                              <br />
                              {data.description}
                              <p>{data.created_at.substring(0, 10)}</p>
                            </Col>
                          </Row>
                        ))}
                  </Tab>
                </Tabs>
              </Col>
            </Row>
          </Col>
          <Col
            xl={4}
            lg={4}
            md={4}
            sm={12}
            xs={12}
            className="recommended-section"
          >
            <Row>
              <Col className="what-shopstick-have-more mt-4">
                <p className="title"> What Genx have more? </p>
                <Row className="more">
                  <Col xs="auto" className="item-img">
                    <img src="/images/payment.png" alt="" />
                  </Col>
                  <Col className="description">
                    <span className="have-one"> Payment </span> <br />
                    <span className="time"> Secured payment gateways </span>
                  </Col>
                </Row>
                <Row className="more">
                  <Col xs="auto" className="item-img">
                    <img src="/images/car-123.png" alt="" />
                  </Col>
                  <Col className="description">
                    <span className="have-one"> Delivery </span> <br />
                    <span className="time"> World wide delivery </span>
                  </Col>
                </Row>
                <Row className="more">
                  <Col xs="auto" className="item-img">
                    <img src="/images/securepay.png" alt="" />
                  </Col>
                  <Col className="description">
                    <span className="have-one"> Warranty </span> <br />
                    <span className="time"> 1 Year manufacturer warranty </span>
                  </Col>
                </Row>
              </Col>
            </Row>
            {/* <Row>
              <Col className="recommended-for-u">
                <p style={{ color: "#898C96", fontSize: "18px" }}>
                  {" "}
                  Recommended for you{" "}
                </p>
                {product.recommended_product.data.map(
                  (relatedProduct, index) => (
                    <Row className="recommended-item" key={index}>
                      <Col xs="auto" className="product">
                        <Link to={"/product-details/" + relatedProduct.slug}>
                          <img
                            src={relatedProduct.image1}
                            alt=""
                            className="image"
                          />
                        </Link>
                      </Col>
                      <Col className="description">
                        <h5> {relatedProduct.name.substring(0, 20)}... </h5>
                        <div
                          className="rating-star"
                          style={{ color: "#F9C732", fontSize: "8px" }}
                        >
                          <Rating
                            emptySymbol="fa fa-star-o fa-2x"
                            fullSymbol="fa fa-star fa-2x"
                            fractions={2}
                            initialRating={
                              relatedProduct.avg_rating[0] != undefined &&
                              relatedProduct.avg_rating[0].rating > 0
                                ? relatedProduct.avg_rating[0].rating
                                : 0
                            }
                            readonly={true}
                          />
                          <span style={{ color: "#40BFFF", fontSize: "18px" }}>
                            {" "}
                            &nbsp;{" "}
                            {relatedProduct.avg_rating[0] != undefined &&
                            relatedProduct.avg_rating[0].rating > 0
                              ? relatedProduct.avg_rating[0].rating
                              : 0}{" "}
                          </span>
                        </div>
                        <p
                          style={{
                            color: "#40BFFF",
                            fontSize: "25px",
                            paddingTop: "8px",
                          }}
                        >
                          <b>
                            {" "}
                            {relatedProduct.discount_price == 0
                              ? relatedProduct.price
                              : relatedProduct.discount_price}{" "}
                            tk{" "}
                          </b>{" "}
                          &nbsp;
                          {relatedProduct.discount_price != 0 && (
                            <del className="product-before-price">
                              {" "}
                              {relatedProduct.price} tk{" "}
                            </del>
                          )}
                        </p>
                      </Col>
                    </Row>
                  )
                )}
              </Col>
            </Row> */}
          </Col>
        </Row>
      </Container>
    </div>
  );
};

const mapStateToProps = ({ cart, favorite, user }) => {
  return { cart: cart.cart, favorite, user };
};
export default connect(mapStateToProps)(ProductDetails);
